| Package: |
| Watersheds |
| Type: |
| Package |
| Version: |
| 1.1 |
| Date: |
| 2016-02-08 |
| License: |
| GPL (>= 2) |
| Depends: |
| R (>= 2.10), methods, sp, maptools, rgeos, lattice, splancs, multicore |
Watershed for identifying the subbasin that contains the current station (class SpatialPoints) and subsets the zhyd object to subbasin and extract the current zhy object that contains station via the S4 method Watershed.Order. Identification of the inlet and outlet stretches and inlet and outlet nodes of the zhyd. Implementation of functions Watershed. ,IOR1, IOR2, IOR3, and IOR4 for determining the actual inlet and outlet nodes. S4 methods Watershed.Order2 and Watershed.Tributary for defining tributary nodes and tributary catchments of the current zhyd watershed.
Watershed and the methods Watershed.Order, Watershed.Order2 and Watershed.Tributary.